# days360

Calculates the days between two dates based on the 360 day year used in interest calculations.
It's planned to add the ISDA and PSA methods in the future.

Implementations are based on https://en.wikipedia.org/wiki/360-day_calendar.

(This library started as a python fork of this ruby gem: https://github.com/tamaloa/days360/tree/master)
